@@ -5,12 +5,16 @@ class Network_UI(UI_Base):
 
     def __init__(self, network, modules=[], label='SORN UI', group_tags=[], transmitters=[], storage_manager=None, group_display_count=None, reduced_layout=False):
 
+        network.simulate_iteration()
+
         network.clear_recorder()
 
+        self.render_every_x_frames=1
+
         #network.simulate_iteration()
-        self.recording = False
-        if self.recording:
-            label += ' rec.'
+        #self.recording = False
+        #if self.recording:
+        #    label += ' rec.'
 
         for ng in network.NeuronGroups:
             if not hasattr(ng, 'color'):
@@ -60,7 +64,7 @@ class Network_UI(UI_Base):
         self.neuron_visible_groups = []
         #self.ts_group = 0
         #self.x_steps = 500
-        self.group_sliders = []
+        #self.group_sliders = []
         self.neuron_select_color = (0, 255, 0, 255)
 
         self.modules = modules
@@ -88,12 +92,19 @@ class Network_UI(UI_Base):
 
     def add_recording_variable(self, group, var, timesteps):
 
-        old_ts=0
-        if var in group._rec_dict:
-            old_ts=group._rec_dict[var]
+        try:
+            n = group  # for eval
+            eval(var) #produce error when not evaluable
 
-        group._rec_dict[var] = max(timesteps,old_ts)
-        #recorder.add_varable('n.output')
+            old_ts=0
+            if var in group._rec_dict:
+                old_ts=group._rec_dict[var]
+
+            group._rec_dict[var] = max(timesteps,old_ts)
+            #recorder.add_varable('n.output')
+            return True
+        except:
+            return False
 
     def init_recoders(self):
         for group_tag in self.group_tags:
@@ -122,12 +133,6 @@ class Network_UI(UI_Base):
         if self.pause:
             self.update_without_state_change=True
 
-
-    def record_image(self, img, key):
-        if self.storage_manager is not None and self.recording:
-            image = upscale(img*255, 10)
-            self.storage_manager.save_frame(image, key)
-
     def get_selected_neuron_subgroup(self):
         syn_sgs = self.get_selected_synapses()
         if len(syn_sgs) > 0:
@@ -177,7 +182,7 @@ class Network_UI(UI_Base):
         if not self.pause or self.step or self.update_without_state_change:
             self.step = False
             if not self.update_without_state_change:
-                for i in range(1):
+                for i in range(self.render_every_x_frames):
                     self.network.simulate_iteration()
 
             self.it = self.network.iteration
@@ -206,7 +211,7 @@ class Network_UI(UI_Base):
 
 
 
-def get_color(type_index, layer):
+def get_color(type_index, layer=1):
     dim_value = max(layer * 0.9, 1.0)
 
     if type_index == 0:
@@ -239,7 +244,7 @@ def get_color(type_index, layer):
 
 ########################################################### Exception handling
 
-
+'''
 
 from io import StringIO
 import traceback
@@ -264,14 +269,15 @@ def excepthook(excType, excValue, tracebackobj):
         ("yourmail at server.com", "")
     versionInfo = "0.0.1"
     timeString = time.strftime("%Y-%m-%d, %H:%M:%S")
-
     tbinfofile = StringIO()
     traceback.print_tb(tracebackobj, None, tbinfofile)
-    tbinfofile.seek(0)
-    tbinfo = tbinfofile.read()
-    errmsg = '%s: \n%s' % (str(excType), str(excValue))
-    sections = [separator, separator, errmsg, separator, tbinfo]
-    msg = '\n'.join(sections)
+    traceback.print_stack()
+    #traceback.print_exc()
+    #tbinfofile.seek(0)
+    #tbinfo = tbinfofile.read()
+    #errmsg = '%s: \n%s' % (str(excType), str(excValue))
+    #sections = [separator, separator, errmsg, separator, tbinfo]
+    #msg = '\n'.join(sections)
     #try:
     #    f = open(logFile, "w")
     #    f.write(msg)
@@ -282,8 +288,12 @@ def excepthook(excType, excValue, tracebackobj):
     #errorbox = QMessageBox()
     #errorbox.setText(str(notice) + str(msg) + str(versionInfo))
     #errorbox.exec_()
+'''
 
-sys.excepthook = excepthook
+def except_hook(cls, exception, traceback):
+    sys.__excepthook__(cls, exception, traceback)
+
+sys.excepthook = except_hook
 
 
 
