@@ -1,6 +1,6 @@
 from time import time
 import numpy as np
-import random
+#import random
 #from NetworkBehaviour.Input.Activator import *
 from PymoNNto.NetworkCore.Base import *
 from PymoNNto.NetworkCore.Synapse_Group import *
@@ -19,16 +19,22 @@ class Network(NetworkObjectBase):
 
         self.iteration = 0
 
-        for k in self.behaviour:
+        for k in sorted(list(self.behaviour.keys())):
             if self.behaviour[k].set_variables_on_init:
                 self.behaviour[k].set_variables(self)
 
 
     def set_mechanisms(self, keys, enabeled):
+        if type(keys) == str:
+            keys = [keys]
         for key in keys:
+            if enabeled:
+                print('activating', key)
+            else:
+                print('deactivating', key)
             for obj in self.all_behaviour_objects():
                 for mechansim in obj[key]:
-                    mechansim.active = enabeled
+                    mechansim.behaviour_enabled = enabeled #changed (active)
 
 
     def deactivate_mechanisms(self, keys):
@@ -61,12 +67,37 @@ class Network(NetworkObjectBase):
             for key in obj.behaviour:
                 b = obj.behaviour[key]
                 current_genome.update(b.set_gene_variables())
-        if info:
-            print('default genome:', current_genome)
+
+        if info and len(current_genome)>0:
+            print('genome:', current_genome)
 
         if storage_manager is not None:
             storage_manager.save_param(key='evolution_params', value=current_genome)
 
+    def __str__(self):
+        neuron_count = np.sum(np.array([ng.size for ng in self.NeuronGroups]))
+        synapse_count = np.sum(np.array([sg.src.size*sg.dst.size for sg in self.SynapseGroups]))
+
+        basic_info = '(Neurons: '+str(neuron_count)+'|'+str(len(self.NeuronGroups))+' groups, Synapses: '+str(synapse_count)+'|'+str(len(self.SynapseGroups))+' groups)'
+
+        result = 'Network'+str(self.tags)+basic_info+'{'
+        for k in sorted(list(self.behaviour.keys())):
+            result += str(k)+':'+str(self.behaviour[k])
+        result += '}'+'\r\n'
+
+        for ng in self.NeuronGroups:
+            result += str(ng)+'\r\n'
+
+        used_tags = []
+        for sg in self.SynapseGroups:
+            tags = str(sg.tags)
+            if tags not in used_tags:
+                result += str(sg)+'\r\n'
+            used_tags.append(tags)
+
+        return result[:-2]
+
+
     def find_objects(self, key):
         result = []
 
@@ -85,12 +116,6 @@ class Network(NetworkObjectBase):
 
         return result
 
-    def print_net_info(self):
-        neuron_count = np.sum(np.array([ng.size for ng in self.NeuronGroups]))
-        sysnape_count = np.sum(np.array([sg.src.size*sg.dst.size for sg in self.SynapseGroups]))
-
-        print('initialize tren... Neurons: ', neuron_count, '|', len(self.NeuronGroups), ' blocks, Synapses: ', sysnape_count, '|', len(self.SynapseGroups),' blocks')
-
     def save_descriptions(self, storage_manager=None):
         if storage_manager is not None:
             return #todo: implement
@@ -102,7 +127,7 @@ class Network(NetworkObjectBase):
         self.set_gene_variables(info=info, storage_manager=storage_manager)
 
         if info:
-            self.print_net_info()
+            print(str(self))
 
         #self.old_param_list = self.get_all_params()
 
@@ -110,7 +135,7 @@ class Network(NetworkObjectBase):
 
         self.behaviour_timesteps = []
 
-        self.add_behaviour_keys_dict(self.behaviour)# todo: test
+        self.add_behaviour_keys_dict(self.behaviour)
 
         for ng in self.NeuronGroups:
             self.add_behaviour_keys_dict(ng.behaviour)
@@ -309,7 +334,7 @@ class Network(NetworkObjectBase):
             '''
 
 
-    def simulate_iterations(self, iterations, batch_size=-1, measure_block_time=False, disable_recording=False):
+    def simulate_iterations(self, iterations, batch_size=-1, measure_block_time=True, disable_recording=False):
 
         if type(iterations) is str:
             iterations=self['Clock', 0].time_to_iterations(iterations)
@@ -345,6 +370,9 @@ class Network(NetworkObjectBase):
         if disable_recording:
             self.recording_on()
 
+        if measure_block_time:
+            print('')
+
         return time_diff
 
 
