@@ -21,7 +21,9 @@ class NeuronGroup(NetworkObjectBase):
             net.NeuronGroups.append(self)
             self.network = net
 
+
         self.size = size
+
         self.afferent_synapses = {} #set by Network
         self.efferent_synapses = {}
 
@@ -38,7 +40,7 @@ class NeuronGroup(NetworkObjectBase):
         #    for k in behaviour:
         #        self.behaviour[k] = copy.copy(behaviour[k])
 
-        for k in self.behaviour:
+        for k in sorted(list(self.behaviour.keys())):
             if self.behaviour[k].set_variables_on_init:
                 self.behaviour[k].set_variables(self)
 
@@ -106,8 +108,8 @@ class NeuronGroup(NetworkObjectBase):
     #def get_neuron_vec(self):
     #    return self.get_nparray((self.size))
 
-    def get_neuron_vec(self, mode='zeros()', scale=None, density=None, plot=False):# mode in ['zeros', 'zeros()', 'ones', 'ones()', 'uniform(...)', 'lognormal(...)', 'normal(...)', ...]
-        return self._get_mat(mode=mode, dim=(self.size), scale=scale, density=density, plot=plot)
+    def get_neuron_vec(self, mode='zeros()', scale=None, density=None, plot=False, kwargs={}, args=[]):# mode in ['zeros', 'zeros()', 'ones', 'ones()', 'uniform(...)', 'lognormal(...)', 'normal(...)', ...]
+        return self._get_mat(mode=mode, dim=(self.size), scale=scale, density=density, plot=plot, kwargs=kwargs, args=args)
 
     def get_neuron_vec_buffer(self, buffer_size):
         return self.get_buffer_mat((self.size), buffer_size)
@@ -131,6 +133,12 @@ class NeuronGroup(NetworkObjectBase):
             source_num += s
         return self.size, source_num
 
+    def __str__(self):
+        result = 'NeuronGroup'+str(self.tags)+'('+str(self.size)+'){'
+        for k in sorted(list(self.behaviour.keys())):
+            result += str(k) + ':' + str(self.behaviour[k])
+        return result+'}'
+
     def subGroup(self, mask=None):
         return NeuronSubGroup(self, mask)
 
@@ -386,4 +394,3 @@ class NeuronSubGroup:
 
     def group_without_subGroup(self):
         return self.BaseNeuronGroup
-
