@@ -1,7 +1,7 @@
 from PymoNNto.NetworkCore.Base import *
 import copy
 
-import random
+#import random
 #def str_eval_conn(eval_string, synapses, s_id, sx, sy, sz, d_id, dx, dy, dz):
 #    return eval(eval_string)
 
@@ -26,7 +26,7 @@ class SynapseGroup(NetworkObjectBase):
 
         self.behaviour = behaviour
 
-        for k in self.behaviour:
+        for k in sorted(list(self.behaviour.keys())):
             if self.behaviour[k].set_variables_on_init:
                 self.behaviour[k].set_variables(self)
 
@@ -94,6 +94,11 @@ class SynapseGroup(NetworkObjectBase):
             self.enabled = connectivity(self, s_id, sx, sy, sz, d_id, dx, dy, dz)
     '''
 
+    def __str__(self):
+        result = 'SynapseGroup'+str(self.tags)+'(D'+str(self.dst.size)+'xS'+str(self.src.size)+'){'
+        for k in sorted(list(self.behaviour.keys())):
+            result += str(k) + ':' + str(self.behaviour[k])+','
+        return result+'}'
 
     def set_var(self, key, value):
         setattr(self,key,value)
@@ -124,8 +129,8 @@ class SynapseGroup(NetworkObjectBase):
     #    print("warning: use get_synapse_mat('uniform',...) instead of get_random_synapse_mat")
     #    return self.get_random_nparray((self.get_synapse_mat_dim()), density, clone_along_first_axis, rnd_code=rnd_code)*self.enabled
 
-    def get_synapse_mat(self, mode='zeros()', scale=None, density=None, only_enabled=True, clone_along_first_axis=False, plot=False):# mode in ['zeros', 'zeros()', 'ones', 'ones()', 'uniform(...)', 'lognormal(...)', 'normal(...)']
-        result = self._get_mat(mode=mode, dim=(self.get_synapse_mat_dim()), scale=scale, density=density, plot=plot)
+    def get_synapse_mat(self, mode='zeros()', scale=None, density=None, only_enabled=True, clone_along_first_axis=False, plot=False, kwargs={}, args=[]):# mode in ['zeros', 'zeros()', 'ones', 'ones()', 'uniform(...)', 'lognormal(...)', 'normal(...)']
+        result = self._get_mat(mode=mode, dim=(self.get_synapse_mat_dim()), scale=scale, density=density, plot=plot, kwargs=kwargs, args=args)
 
         if clone_along_first_axis:
             result = np.array([result[0] for _ in range(self.get_synapse_mat_dim()[0])])
@@ -208,6 +213,8 @@ class SynapseGroup(NetworkObjectBase):
     def get_sub_synapse_group(self, src_mask, dst_mask):
         result = SynapseGroup(self.src.subGroup(src_mask), self.dst.subGroup(dst_mask), net=None, behaviour={})
 
+        #result.original_synapse_group = self
+
         # partition enabled update
         if type(self.enabled) is np.ndarray:
             mat_mask = dst_mask[:, None] * src_mask[None, :]
